for X IPE, my idea is, usually it used to transparent application works build by Agent. the folder structure I can expect as below
- project root
- x-ipe
   > x-ipe codes
- .github/skills
- docs
...

so can we have a predefined project root point to project root, which is upper level of x-ipe, and another point to x-ipe
and have instructions to start x-ipe if it's in a sub folder for project root